==> self_encryption-0.32.0.tar.gz: self_encryption-0.32.0/examples/parallel_streaming_decryptor.rs <==
use bytes::Bytes;
use self_encryption::{
    streaming_decrypt_from_storage, DataMap, Error, Result, deserialize
};
use std::{
    fs::File,
    io::Read,
    path::Path,
};
use rayon::prelude::*;
use xor_name::XorName;

fn main() -> Result<()> {
    // Load the data map from file or another source
    let data_map = load_data_map("path/to/data_map")?;

    // Implement the parallel chunk retrieval function
    let get_chunk_parallel = |hashes: &[XorName]| -> Result<Vec<Bytes>> {
        hashes
            .par_iter()
            .map(|hash| {
                // Simulate network retrieval with local file read
                let chunk_path = Path::new("chunks").join(hex::encode(hash));
                let mut chunk_data = Vec::new();
                File::open(&chunk_path)
                    .and_then(|mut file| file.read_to_end(&mut chunk_data))
                    .map_err(|e| Error::Generic(format!("Failed to read chunk: {}", e)))?;
                Ok(Bytes::from(chunk_data))
            })
            .collect()
    };

    // Use the streaming decryption function
    streaming_decrypt_from_storage(
        &data_map,
        Path::new("output_file.dat"),
        get_chunk_parallel,
    )?;

    Ok(())
}

// Helper function to load data map from a file
fn load_data_map(path: &str) -> Result<DataMap> {
    let mut file = File::open(path)
        .map_err(|e| Error::Generic(format!("Failed to open data map: {}", e)))?;
    let mut data = Vec::new();
    file.read_to_end(&mut data)
        .map_err(|e| Error::Generic(format!("Failed to read data map: {}", e)))?;
    deserialize(&data)
}

==> self_encryption-0.32.3.tar.gz: self_encryption-0.32.3/examples/parallel_streaming_decryptor.rs <==
use bytes::Bytes;
use rayon::prelude::*;
use self_encryption::{deserialize, streaming_decrypt_from_storage, DataMap, Error, Result};
use std::{fs::File, io::Read, path::Path};
use xor_name::XorName;

fn main() -> Result<()> {
    // Load the data map from file or another source
    let data_map = load_data_map("path/to/data_map")?;

    // Implement the parallel chunk retrieval function
    let get_chunk_parallel = |hashes: &[XorName]| -> Result<Vec<Bytes>> {
        hashes
            .par_iter()
            .map(|hash| {
                // Simulate network retrieval with local file read
                let chunk_path = Path::new("chunks").join(hex::encode(hash));
                let mut chunk_data = Vec::new();
                File::open(&chunk_path)
                    .and_then(|mut file| file.read_to_end(&mut chunk_data))
                    .map_err(|e| Error::Generic(format!("Failed to read chunk: {}", e)))?;
                Ok(Bytes::from(chunk_data))
            })
            .collect()
    };

    // Use the streaming decryption function
    streaming_decrypt_from_storage(&data_map, Path::new("output_file.dat"), get_chunk_parallel)?;

    Ok(())
}

// Helper function to load data map from a file
fn load_data_map(path: &str) -> Result<DataMap> {
    let mut file =
        File::open(path).map_err(|e| Error::Generic(format!("Failed to open data map: {}", e)))?;
    let mut data = Vec::new();
    file.read_to_end(&mut data)
        .map_err(|e| Error::Generic(format!("Failed to read data map: {}", e)))?;
    deserialize(&data)
}
